@@ -3,6 +3,7 @@ import cgi
 import logging
 import marshal
 import base64
+from datetime import timedelta
 from hashlib import sha1
 from StringIO import StringIO
 from tempfile import TemporaryFile
@@ -240,9 +241,12 @@ class Response(Exception):
             *key        - (unicode) ключ
             *val        - (unicode) значение
             **path      - (unicode) uri, '/' - для действия на весь домен
-            **expires   - (int) время жизни куки в секундах, дефолт - до закрытия браузера
+            **expires   - (int, datetime) время жизни куки в секундах, дефолт - до закрытия браузера
             **domain    - (unicode) дефолт - текущий поддомен, '.site.name' - для всех поддоменов
         """
+        expires = kwargs.get('expires')
+        if expires and isinstance(expires, timedelta):
+            kwargs['expires'] = expires.days * 86400 + expires.seconds 
         key = key.encode(self.charset, self.encoding_errors)
         self.COOKIES[key] = val.encode(self.charset, self.encoding_errors)
         self.COOKIES[key]['path'] = path
